@@ -1,4 +1,4 @@
-//$Id: button-prop.cc,v 1.18 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: button-prop.cc,v 1.19 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,7 +27,7 @@
 #include <gtk--/menu.h>
 
 #include "widget-prop.h"
-#include "resizeable-prop.h"
+#include "auto-resizeable-prop.h"
 #include "textual-prop.h"
 
 using namespace Guikachu::GUI::FormEditor;
@@ -95,7 +95,8 @@ ButtonProperties::ButtonProperties (Button *res_):
     WidgetProperties::add_position_controls (res, *proptable);
     
     /* Size */
-    ResizeableProperties::add_controls (res, *proptable);
+    AutoWidthProperties::add_controls  (res, *proptable);
+    AutoHeightProperties::add_controls (res, *proptable);
     
     proptable->show ();
     property_editor = proptable;
