@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.29 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.31 2002/01/28 18:21:58 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,7 +28,10 @@ Button::Button (Resources::Form   *owner,
 		const std::string &id):
     Widget (owner, id),
     Resizeable (changed),
+    AutoWidth (changed),
+    AutoHeight (changed),
     Textual (changed, id),
+    
     editor (0),
     frame (changed, BUTTON_FRAME_SIMPLE),
     usable (changed, true),
