@@ -1,4 +1,4 @@
-//$Id: checkbox.h,v 1.14 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.h,v 1.15 2002/01/26 00:19:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,7 +28,7 @@ namespace Guikachu
 }
 
 #include "widget.h"
-#include "resizeable.h"
+#include "auto-resizeable.h"
 #include "textual.h"
 
 #include "checkbox-prop.h"
@@ -38,7 +38,8 @@ namespace Guikachu
     namespace Widgets
     {
 	class Checkbox: public Widget,
-			public Resizeable,
+			public AutoWidth,
+			public AutoHeight,
 			public Textual
 	{
 	    GUI::FormEditor::CheckboxProperties *editor;
