@@ -1,4 +1,4 @@
-//$Id: font.h,v 1.6 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: font.h,v 1.7 2002/01/12 14:12:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,6 +39,7 @@ namespace Guikachu
 		bool         **bitmap;
 	    public:
 		Glyph (std::istream &stream, unsigned int &height);
+		Glyph (unsigned int height, unsigned int ascent); // Create placeholder glyph
 	    };
 	    
 	    class Font
@@ -61,6 +62,9 @@ namespace Guikachu
 		int get_height  () const { return height; };
 		int get_ascent  () const { return ascent; };
 		int get_descent () const { return descent; };
+
+	    private:
+		const Glyph& get_glyph (char c) const;
 	    };
 	}
     }
