@@ -1,4 +1,4 @@
-//$Id: form.h,v 1.15 2002/01/01 21:23:40 cactus Exp $ -*- c++ -*-
+//$Id: form.h,v 1.17 2002/02/05 15:08:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -58,14 +58,13 @@ namespace Guikachu
 	    // FormElement methods
 	    int get_x () const { return res->x; };
 	    int get_y () const { return res->y; };
+	    void set_x (int x) { res->x = x; };
+	    void set_y (int y) { res->y = y; };
 	    
 	    Gtk::Widget                     *get_editor      ();
 	    GUI::FormEditor::FormCanvasItem *get_canvas_item (Gnome::CanvasGroup *parent_group);
 
 	    Resources::Form *get_resource () const { return res; };
-	    
-	    SigC::Signal1<void, bool> selected;
-	    SigC::Signal0<void>       request_edit;
 	};
     }
 }
