@@ -1,4 +1,4 @@
-//$Id: list-prop.cc,v 1.13 2002/01/05 23:35:20 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.14 2002/02/23 20:37:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,6 +34,7 @@
 #include <gtk--/notebook.h>
 
 #include "widget-prop.h"
+#include "auto-resizeable-prop.h"
 
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
@@ -72,11 +73,7 @@ ListProperties::ListProperties (List *res)
     WidgetProperties::add_position_controls (res, *proptable);
 
     /* Width */
-    control = new GUI::PropertyEditors::WidthEntry (res->width);
-    control = new GUI::PropertyEditors::AutoToggle (*manage (control), res->manual_width);
-    proptable->add (_("_Width:"), *manage (control),
-		    _("Horizontal size of the widget "
-		      "(check to set manually)"));
+    AutoWidthProperties::add_controls (res, *proptable);
 
     // FIXME: Add uline accelerators to the tabs
     notebook->pages ().push_back (
