@@ -1,4 +1,4 @@
-//$Id: resizeable-canvas.cc,v 1.8 2002/02/09 17:54:06 cactus Exp $ -*- c++ -*-
+//$Id: resizeable-canvas.cc,v 1.10 2002/02/23 22:01:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,7 +30,7 @@ ResizeableCanvasItem::ResizeableCanvasItem (Widgets::Resizeable *resizeable_,
     grip_group (0)
 {
     canvas_item_changed.connect (SigC::slot (this, &ResizeableCanvasItem::canvas_item_changed_cb));
-    resizeable->selected.connect (SigC::slot (this, &ResizeableCanvasItem::selected_cb));
+    resizeable->selected_last.connect (SigC::slot (this, &ResizeableCanvasItem::selected_last_cb));
 }
 
 ResizeableCanvasItem::~ResizeableCanvasItem ()
@@ -87,7 +87,7 @@ CanvasGrip *ResizeableCanvasItem::create_grip (int x, int y, Corner corner)
     return grip;
 }
 
-void ResizeableCanvasItem::selected_cb (bool selected)
+void ResizeableCanvasItem::selected_last_cb (bool selected)
 {
     if (selected)
     {
@@ -214,11 +214,16 @@ void ResizeableCanvasItem::grip_drag_motion_cb (int dx, int dy,
     resizeable->width = new_width;
     resizeable->height = new_height;
 
+    // Position delta is recalculated to work with widgets that
+    // override the width and/or height property from get_display_*
+    int pos_dx = resizeable->get_display_width  () - drag_context.start_width;
+    int pos_dy = resizeable->get_display_height () - drag_context.start_height;
+
     if (corner == CORNER_NW || corner == CORNER_SW)
-	resizeable->set_x (drag_context.start_x - real_dx);
+	resizeable->set_x (drag_context.start_x - pos_dx);
 
     if (corner == CORNER_NW || corner == CORNER_NE)
-	resizeable->set_y (drag_context.start_y - real_dy);
+	resizeable->set_y (drag_context.start_y - pos_dy);
 }
 
 void ResizeableCanvasItem::get_delta_constraints (int &dx_min, int &dx_max,
