@@ -1,4 +1,4 @@
-//$Id: text-field.cc,v 1.9 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
+//$Id: text-field.cc,v 1.11 2002/02/10 00:01:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,6 +28,7 @@ TextField::TextField (Resources::Form   *owner,
 		      const std::string &id):
     Widget (owner, id),
     Resizeable (changed),
+    AutoHeight (changed),
     editor (0),
     
     usable (changed, true),
@@ -44,6 +45,7 @@ TextField::TextField (Resources::Form   *owner,
     justify_right (changed, false),
     has_scrollbar (changed, false)
 {
+    width = 30;
 }
 
 TextField::~TextField ()
@@ -81,12 +83,14 @@ bool TextField::load (StorageNode &node)
 	    y = curr_node.get_prop<int> ("y");
 
 	    std::string width_str = curr_node.get_prop<std::string> ("width");
+
+	    /*
+	     *Evil hack: handle 1.0 Guikachu files which sometimes saved 'auto'
+	     * when width was 30
+	     */
 	    if (width_str == "auto")
-	    {
-		manual_width = false;
-		width = 0;
-	    } else {
-		manual_width = true;
+		width = 30;
+	    else {
 		width = atoi (width_str.c_str ());
 	    }
 	    
@@ -144,10 +148,7 @@ void TextField::save (StorageNode &node) const
     my_node.set_prop ("y", y);
 
     /* Size */
-    if (manual_width)
-	my_node.set_prop ("width", width);
-    else
-	my_node.set_prop ("width", "auto");
+    my_node.set_prop ("width", width);
 
     if (manual_height)
 	my_node.set_prop ("height", height);
@@ -243,11 +244,6 @@ void TextField::save_rcp (std::ostream &ostr) const
     ostr << std::endl;
 }
 
-int TextField::get_auto_width () const
-{
-    return 30;
-}
-
 int TextField::get_display_height () const
 {
     int min_height = get_auto_height ();
