@@ -1,6 +1,6 @@
-//$Id: widget.cc,v 1.16 2001/12/19 22:04:00 cactus Exp $ -*- c++ -*-
+//$Id: widget.cc,v 1.18 2002/01/01 21:23:41 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -59,13 +59,13 @@ Gtk::Widget* Widget::get_editor ()
     return editor;
 }
 
-GUI::FormEditor::CanvasItem* Widget::get_canvas_item (GUI::FormEditor::Form *form)
+GUI::FormEditor::WidgetCanvasItem* Widget::get_canvas_item (Gnome::CanvasGroup *parent_group)
 {
-    GUI::FormEditor::CanvasItem *ret;
+    GUI::FormEditor::WidgetCanvasItem *ret;
     
-    canvas_item_map_t::iterator found = canvas_items.find (form);
+    canvas_item_map_t::iterator found = canvas_items.find (parent_group);
     if (found == canvas_items.end ())
-	ret = canvas_items[form] = create_canvas_item (form);
+	ret = canvas_items[parent_group] = create_canvas_item (parent_group);
     else
 	ret = found->second;
 
