@@ -1,4 +1,4 @@
-//$Id: preferences-win.cc,v 1.5 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
+//$Id: preferences-win.cc,v 1.6 2002/02/10 14:11:47 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,6 +19,9 @@
 #include "preferences-win.h"
 #include "preferences.h"
 
+#include "config.h"
+#include <libgnome/libgnome.h>
+
 #include "argumentsink.h"
 #include <gtk--/adjustment.h>
 
@@ -33,17 +36,18 @@ namespace {
 
 using namespace Guikachu;
 
-GUI::PreferencesWin::PreferencesWin ()
+GUI::PreferencesWin::PreferencesWin ():
+    gui (glade_xml_new (GUIKACHU_GLADEDIR "/guikachu.glade", "preferences")),
+
+    prop_box        (Gtk::wrap (GNOME_PROPERTY_BOX (glade_xml_get_widget (gui, "preferences")))),
+    color_fg        (Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_fg")))),
+    color_disabled  (Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_disabled")))),
+    color_bg        (Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_bg")))),
+    color_selection (Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_sel")))),
+    spin_zoom       (Gtk::wrap (GTK_SPIN_BUTTON    (glade_xml_get_widget (gui, "pref_zoom"))))
 {
-    gui = glade_xml_new (GUIKACHU_GLADEDIR "/guikachu.glade", "preferences");
-
-    prop_box        = Gtk::wrap (GNOME_PROPERTY_BOX (glade_xml_get_widget (gui, "preferences")));
-    color_fg        = Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_fg")));
-    color_disabled  = Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_disabled")));
-    color_bg        = Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_bg")));
-    color_selection = Gtk::wrap (GNOME_COLOR_PICKER (glade_xml_get_widget (gui, "pref_color_sel")));
-    spin_zoom       = Gtk::wrap (GTK_SPIN_BUTTON (glade_xml_get_widget (gui, "pref_zoom")));
-
+    prop_box->set_title (_("Preferences"));
+    
     // Set up 'changed' signals so that the 'Apply' button is made sensitive
     color_fg->color_set.connect (
 	SigC::hide <void, guint, guint, guint, guint> (
