@@ -1,6 +1,6 @@
-//$Id: resource-manager-io.cc,v 1.22 2001/12/19 22:03:59 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.27 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -30,6 +30,8 @@
 #include <fcntl.h>
 #include <unistd.h>
 
+#include "target.h"
+
 #include "storage.h"
 
 using namespace Guikachu;
@@ -43,10 +45,20 @@ void ResourceManager::reset ()
 	remove_resource ((i++)->second);
     
     if (!app)
+    {
 	app = new Resources::Application ();
+	app->changed.connect (SigC::slot(&ResourceManager::set_dirty));
+    }
     else
 	app->reset ();
 
+    if (!target)
+    {
+	target = new Target ();
+	target->changed.connect (SigC::slot(&ResourceManager::set_dirty));
+    }
+    target->load_stock (Target::get_default_stock_id ());
+
     clear_dirty ();
 }
 
@@ -77,6 +89,8 @@ ResourceManager::IOResult ResourceManager::load (const std::string &filename)
     {
 	if (curr_node.name () == "application")
 	    app->load (curr_node);
+	else if (curr_node.name () == "target")
+	    target->load (curr_node);
 	else
 	    load_resource (curr_node);
     }
@@ -129,6 +143,10 @@ ResourceManager::IOResult ResourceManager::save (const std::string &filename)
     // Save per-application data
     node = root.add_node ("application");
     app->save (node);
+
+    // Save target machine data
+    node = root.add_node ("target");
+    target->save (node);
     
     // Save resources
     for (std::map<std::string, Resource*>::iterator i = resource_map.begin ();
@@ -136,7 +154,7 @@ ResourceManager::IOResult ResourceManager::save (const std::string &filename)
 	 i++)
     {
 	Resource *resource = i->second;
-	std::string curr_node_name = Resources::prefix_from_type (resource->get_type ());
+	std::string curr_node_name = Resources::type_id_from_type (resource->get_type ());
 
 	node = root.add_node (curr_node_name);
 	node.set_prop ("id", resource->id);
