@@ -1,6 +1,6 @@
-//$Id: resource-manager.h,v 1.17 2001/12/21 17:17:44 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.21 2002/01/01 21:23:39 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -41,6 +41,9 @@ namespace Guikachu
 	int  compare     (const std::string &x, const std::string &y) const;
 	bool operator () (const std::string &x, const std::string &y) const;
     };
+
+    // Forward declarations
+    class Target;
     
     class ResourceManager: public SigC::Object
     {
@@ -50,8 +53,9 @@ namespace Guikachu
 	static resource_map_t          resource_map;
 	static id_set_t                id_set;
 	static bool                    dirty;
-	static time_t                  last_save_time;
+	static time_t                  modification_time;
 	static Resources::Application *app;
+	static Target                 *target;
 
     public:
 	static Resource* create_resource (Resources::Type type,
@@ -69,6 +73,7 @@ namespace Guikachu
 	static std::set<Resource*>     get_resources   ();
 	static Resource*               get_resource    (const std::string &id);
 	static Resources::Application* get_application () { return app; };
+	static Target*                 get_target      () { return target; };
 	
 	// Signals
 	static SigC::Signal1<void, Resource*> resource_created;
@@ -82,16 +87,17 @@ namespace Guikachu
 	    IO_INVALID
 	};
 	
-	static void     reset         ();
-	static bool     is_dirty      ();
-	static time_t   get_last_save ();
+	static void     reset    ();
+	static bool     is_dirty ();
+	static time_t   get_modification_time ();
+	
 	static IOResult load       (const std::string &filename);
 	static IOResult save       (const std::string &filename);
 	static void     export_rcp (const std::string &filename); 
 
     private:
 	static void clear_dirty ();
-	static void resource_changed_cb ();
+	static void set_dirty ();
 	static Resource* load_resource (StorageNode &node);
     };
 }
