@@ -1,6 +1,6 @@
-//$Id: pos-entry.cc,v 1.4 2001/12/19 17:56:53 cactus Exp $ -*- c++ -*-
+//$Id: pos-entry.cc,v 1.6 2002/01/01 21:23:42 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -16,17 +16,34 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
 
-#include "pos-entry.h"
+#include "widgets/pos-entry.h"
 #include "form-editor/form-editor.h"
 
+#include "resource-manager.h"
+#include "target.h"
+
 using namespace Guikachu::GUI::PropertyEditors;
 
 XPosEntry::XPosEntry (Property<int> &property):
-    NumEntry (0, (GUIKACHU_SCREEN_WIDTH - 1), property)
+    NumEntry (0, GUIKACHU_SCREEN_WIDTH - 1, property)
 {
+    ResourceManager::get_target ()->changed.connect (
+	SigC::slot (this, &XPosEntry::target_changed_cb));
+}
+
+void XPosEntry::target_changed_cb ()
+{
+    get_adjustment ()->set_upper (GUIKACHU_SCREEN_WIDTH - 1);
 }
 
 YPosEntry::YPosEntry (Property<int> &property):
     NumEntry (0, (GUIKACHU_SCREEN_HEIGHT - 1), property)
 {
+    ResourceManager::get_target ()->changed.connect (
+	SigC::slot (this, &YPosEntry::target_changed_cb));
+}
+
+void YPosEntry::target_changed_cb ()
+{
+    get_adjustment ()->set_upper (GUIKACHU_SCREEN_HEIGHT - 1);
 }
