@@ -1,6 +1,6 @@
-//$Id: propertytable.cc,v 1.16 2001/12/19 22:04:02 cactus Exp $ -*- c++ -*-
+//$Id: propertytable.cc,v 1.18 2002/01/03 17:19:35 cactus Exp $ -*- c++ -*-
 
-/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
+/* Guikachu Copyright (C) 2001-2002 RDI Gerg <cactus@cactus.rulez.org>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License version 2
@@ -117,6 +117,9 @@ void PropertyTable::add (const std::string &label,
 			 const std::string &tooltip = "")
 {
     Gtk::Widget *label_widget = create_label (label, control, tooltip);
+    control.set_data ("label_widget", label_widget);
+
+    label_widget->show ();
     control.show ();
 
     attach (*manage (label_widget),
@@ -159,6 +162,31 @@ void PropertyTable::add_separator ()
     curr_row++;
 }
 
+void PropertyTable::set_child_sensitive (Gtk::Widget &child, bool sensitive)
+{
+    Gtk::Widget *label = dynamic_cast<Gtk::Widget*>((Gtk::Widget*)child.get_data ("label_widget"));
+    g_return_if_fail (label != 0);
+
+    child.set_sensitive (sensitive);
+    label->set_sensitive (sensitive);
+}
+
+void PropertyTable::set_child_shown (Gtk::Widget &child, bool shown)
+{
+    Gtk::Widget *label = dynamic_cast<Gtk::Widget*>((Gtk::Widget*)child.get_data ("label_widget"));
+    g_return_if_fail (label != 0);
+
+    if (shown)
+    {
+	child.show ();
+	label->show ();
+    } else {
+	child.hide ();
+	label->hide ();
+    }
+}
+
+
 void PropertyTable::parent_changed_cb (Gtk::Widget *old_parent)
 {
     if (old_parent)
